/**
 * Mention resolver module.
 *
 * @module mention
 * @example
 * let { getHtml } = peepso.modules.mention;
 *
 * getHtml( 'user', 99, 'User' )
 *     .then( data => console.log( data ) )
 *     .catch( error => console.error( error ) );
 */

import { Promise } from 'peepso';

/**
 * Mention HTML cache.
 *
 * @type {Object.<string>}
 * @private
 */
const cache = {};

/**
 * Get the mention HTML.
 *
 * @param {string} type
 * @param {number} id
 * @param {string} [name]
 * @returns {Promise.<string,?string>}
 */
export function getHtml( type, id, name ) {
	return new Promise( ( resolve, reject ) => {
		let endpoint = 'mentionsajax.get_mention',
			params = { type, id, name },
			cacheKey = `${ type }_${ id }${ name ? '_' + name : '' }`,
			transport,
			json;

		// Get HTML from cache if it is already available.
		if ( cache[ cacheKey ] ) {
			resolve( cache[ cacheKey ] );
			return;
		}

		transport = peepso.postJson( endpoint, params ).ret;
		transport
			.done( resp => ( json = resp ) )
			.always( () => {
				if ( json && json.success && ! json.errors ) {
					if ( json.data && json.data.html ) {
						let html = json.data.html;
						cache[ cacheKey ] = html;
						resolve( html );
						return;
					}
				}

				let error = ( json && json.errors && json.errors.join( '\n' ) ) || undefined;
				reject( error );
			} );
	} );
}
